@@ -26,6 +26,7 @@ import charms.reactive.bus
 import charmhelpers.contrib.hahelpers.cluster as ch_cluster
 import charmhelpers.contrib.network.ip as ch_ip
 import charmhelpers.contrib.openstack.context as ch_context
+import charmhelpers.contrib.openstack.ip as ch_os_ip
 import charmhelpers.contrib.openstack.utils as ch_utils
 import charmhelpers.core.hookenv as hookenv
 import charmhelpers.core.host as ch_host
@@ -302,13 +303,18 @@ class PeerHARelationAdapter(OpenStackRelationAdapter):
         self.api_config_adapter = APIConfigurationAdapter()
         self.local_address = self.api_config_adapter.local_address
         self.local_unit_name = self.api_config_adapter.local_unit_name
-        # Note(AJK) - bug #1698814 - cluster_hosts needs to be ordered so that
-        # re-writes with no changed data don't cause a restart (dictionaries
-        # are 'randomly' ordered)
+        # Note(ajkavanagh) - bug #1698814 - cluster_hosts needs to be ordered
+        # so that re-writes with no changed data don't cause a restart
+        # (dictionaries are 'randomly' ordered)
         self.cluster_hosts = collections.OrderedDict()
         if relation:
-            self.add_network_split_addresses()
+            # NOTE(ajkavanagh) BUG: #1912505
+            # do add_default_addresses first, then add_network_split_addresses
+            # as otherwise it will inadvertently overwrite the correct
+            # addresses with the private-addresses of the remove units (rather
+            # the the address that is required)
             self.add_default_addresses()
+            self.add_network_split_addresses()
 
     @property
     def internal_addresses(self):
@@ -793,7 +799,7 @@ class APIConfigurationAdapter(ConfigurationAdapter):
             addr = ch_ip.get_ipv6_addr(exc_list=[self.vip])[0]
         else:
             addr = ch_utils.get_host_ip(
-                hookenv.unit_get('private-address'))
+                ch_os_ip.local_address(unit_get_fallback='private-address'))
         return addr
 
     @property
@@ -987,7 +993,8 @@ class APIConfigurationAdapter(ConfigurationAdapter):
             if hookenv.config(net_cfg_opt):
                 addr = ch_ip.get_address_in_network(
                     config_cidr,
-                    hookenv.unit_get('private-address'))
+                    ch_os_ip.local_address(
+                        unit_get_fallback='private-address'))
             else:
                 addr = ch_ip.get_relation_ip(
                     os_ip.ADDRESS_MAP[net_type]['binding'])
